//Bibliothek zum ansteuern des LCD-Displays
#include <LiquidCrystal_I2C.h>
//Bibliothek zum auslesen des DHTx Sensors
#include <DHT.h>

//DHT11 Sensor am digitalen Pin D9 angeschlossen
#define sensor 9
//definieren das wir einen DHT Sensor vom Typ DHT11 verwenden
#define DHTTYPE DHT11

//initialisieren eines Objektes vom Typ LiquidCrystal_I2C
LiquidCrystal_I2C lcd(0x27, 16, 2);
//initialisieren eines Objektes vom Typ DHT
DHT dhtSensor(sensor, DHTTYPE);

void setup() {
  //begin der kommunikation mit dem DHT Sensor
  dhtSensor.begin();
  //begin der kommunikation mit dem konfigurierten LCD-Display
  lcd.init();
  //aktivieren der Hintergrundbeleuchtung
  lcd.backlight();
}

//Funktion zum schreiben eines Textes auf dem LCD-Display
void writeText(int line, String lbl, float value, String sign) {
  //setzen der Cursor-Position
  lcd.setCursor(0, line);
  //zusammensetzen und schreiben eines Textes
  //der Wert der Variable "value" wird auf eine Nachkommastelle gekürzt
  lcd.print(lbl + String(value, 1) + sign);
}

void loop() {
  //kleine Pause von 1500 Millisekunden
  delay(1500);
  //auslesen der Sensorwerte
  float humidityVal = dhtSensor.readHumidity();
  float tempVal = dhtSensor.readTemperature();

  //prüfen ob die Werte korrekt ausgelesen wurden
  if (isnan(humidityVal) || isnan(tempVal)) {
    Serial.println("Fehler beim lesen der Daten vom DHT11 Sensor!");
    return;
  }
  //den Text vom Display löschen
  lcd.clear();
  //schreiben der Temperatur auf die erste Zeile
  writeText(0, "Temp. ", tempVal, "C");
  //schreiben der rel. Luftfeuchtigkeit auf die zweite Zeile
  writeText(1, "rel.Lft. ", humidityVal, "%");
}
